# -*- coding: utf-8 -*-
'''
Updates all Feeds
'''
from django.core.management.base import NoArgsCommand

from articles.models import Feed
import os
import datetime

REFRESH_LOCK = '/var/lock/loco-directory/refresh'


class Command(NoArgsCommand):
    help = "Updates all Feeds in the database."

    def handle_noargs(self, **options):
        verbosity = int(options.get('verbosity', 1))

        # obtain lock
        if not os.path.exists(os.path.dirname(REFRESH_LOCK)):
            if verbosity >= 2:
                print "Creating lock file directory"
            os.mkdir(os.path.dirname(REFRESH_LOCK))

        if os.path.exists(REFRESH_LOCK):
            if verbosity >= 2:
                print "Lock file exists, exiting"
            return
        else:
            if verbosity >= 2:
                print "Creating lock file"
            lock = open(REFRESH_LOCK, 'w')
            if not lock:
                if verbosity >= 1:
                    print "Failed to create the lock file"
                raise Exception("Failed to open lock file")
            lock.write('%s\n' % os.getpid())
            lock.close()

        try:
            if verbosity >= 2:
                print "Processing feeds"
            # Process feeds
            for feed in Feed.objects.filter(active=True):
                if verbosity >= 2:
                    print "[%s] Updating: %s" % (datetime.datetime.now(), feed.title)
                try:
                    feed.update()
                except Exception, e:
                    print "Error reading %s: %s" % (feed.url, e)
        except Exception, e:
            print "Error refreshing feeds: %s" % e
        finally:
            # release lock
            os.remove(REFRESH_LOCK)
