from django.template import Context, loader
from django import forms
from django.utils.translation import ugettext as _

import datetime

# Taken from http://djangosnippets.org/snippets/1732/
class RenderableMixin(object):
    """
    Mixin to render forms from a predefined template
    """

    @property
    def form_class_name(self):
        return '.'.join([self.__module__, self.__class__.__name__.lower()])

    def as_template(self):
        """
        Renders a form from a template
        """
        self.template_name = self.__class__.__name__.lower()

        if not getattr(self, 'tpl', None):
            self.tpl = loader.get_template('form.html')

        context_dict = dict(
            non_field_errors=self.non_field_errors(),
            fields=[forms.forms.BoundField(self, field, name) for name, field in self.fields.iteritems()],
            errors=self.errors,
            data=self.data,
            form=self,
        )

        if getattr(self, 'initial', None):
            context_dict.update(dict(initial=self.initial))
        if getattr(self, 'instance', None):
            context_dict.update(dict(instance=self.instance))
        if getattr(self, 'cleaned_data', None):
            context_dict.update(dict(cleaned_data=self.cleaned_data))

        return self.tpl.render(
            Context(context_dict)
        )


class SiteSearchForm(forms.Form):
    """
    A Search form for the whole site
    """
    q = forms.CharField(label=_('Search'), required=False, max_length=100)

    def as_line(self):
        "Returns this form rendered. Only the fields. Nothing else HTML."
        return self._html_output(u'%(label)s %(errors)s%(field)s%(help_text)s', u'%s', '', u'%s', False)


class FilterHistoryList(forms.Form):
    """
    a form to filter event history list
    """

    choices = [('all', _(u'all')), ('my', _(u'month and year')), ('y', _(u'only year'))]

    scope = forms.ChoiceField(choices)

    now = datetime.datetime.now().strftime("%Y-%m")
    filtering = forms.CharField(required=False, initial=now)

    class Media:
        css = {'all': (
                       '/media/jquery-ui/css/css/smoothness/jquery-ui.css',
                       '/media/jquery-ui-timepicker/css/ui-lightness/ui.timepickr.css',
                       '/media/css/colortip-1.0-jquery.css',
                       '/media/css/newstyle.css',
                       )}
        js = (
              '/media/jquery/jquery.js',
              '/media/jquery-ui/jquery-ui.js',
              '/media/jquery-ui-timepicker/js/jquery.timepickr.min.js',
              '/media/jquery-ui-timepicker/js/ui.timepickr.min.js',
              '/media/js/colortip-1.0-jquery.js',
              '/media/js/events-ui.js',
              )
