# -*- coding: utf-8 -*-
#!/usr/bin/python

from django.core.management.base import NoArgsCommand
from django.contrib.auth.models import Group

import settings
import subprocess
import sys
import os

import logging
logging.basicConfig()
log = logging.getLogger(__name__)


class Command(NoArgsCommand):
    help = "Make sure the LoCo Team Portal is set up properly."

    def handle_noargs(self, **options):

        log.info("Compiling messages.")
        subprocess.call([sys.executable, "manage.py", "compilemessages"])

        (lc, new_object) = Group.objects.get_or_create(name="ubuntu-lococouncil")
        if new_object:
            lc.save()
            stat = "added"
        else:
            stat = "yes"
        log.info("Checking if LoCo Council is in Auth teams : %s." % stat)

        updated = False
        path = settings.PROJECT_PATH
        javascript_dir = "/usr/share/javascript"
        media_dir = os.path.join(path, "media")
        link_mapping = [("libjs-jquery", "jquery"),
                        ("libjs-jquery-ui", "jquery-ui")]
        for (package, pathname) in link_mapping:
            src = os.path.join(javascript_dir, pathname)
            if not os.path.exists(src):
                log.critical("Please install the %s package." % package)
                sys.exit(1)
            dest = os.path.join(media_dir, pathname)
            if not os.path.exists(dest):
                os.symlink(src, dest)
                updated = True
        if updated:
            log.info("Creating jquery symlinks: updated.")
        else:
            log.info("Creating jquery symlinks: not necessary.")

        if os.path.isdir(os.path.join(path, "bzr_apps", ".bzr")):
            log.info("Adding Bzr Apps : not necessary.")
        else:
            subprocess.call(["bzr", "branch", "-q", "--use-existing-dir",
                             "lp:ubuntu-django-foundations/bzr-apps",
                             "bzr_apps"])
            log.info("Bzr Apps added.")
