import pytz


class LocalTimeMixin(object):
    '''Provides methods for converting between UTC and localtime

    Classes using this should provide the timezone string as self.tz
    '''

    def get_timezone(self):
        'Returns the pytz timezone instance for this object\'s timezone'
        try:
            return pytz.timezone(self.tz)
        except:
            return pytz.utc
    timezone = property(get_timezone)

    def tolocaltime(self, dt):
        'Converts a datetime in UTC to a datetime in this object\'s timezone'
        if dt is None:
            return None
        as_utc = pytz.utc.localize(dt)
        return as_utc.astimezone(self.timezone)

    def fromlocaltime(self, dt):
        'Converts a datetime in this object\'s timezone to a datetime in UTC'
        if dt is None:
            return None
        local = self.timezone.localize(dt)
        return local.astimezone(pytz.utc)
