# -*- coding: utf-8 -*-
from django.utils.encoding import smart_unicode
from django.conf import settings

import subprocess
import datetime
import email
import os
from copy import deepcopy
import re
import unicodedata

# Extra characters outside of alphanumerics that we'll allow.
SLUG_OK = '-_~'
languages = None


def write_log(job_name, log):
    stamp_dir = os.path.join(settings.PROJECT_PATH, 'data')
    log_file = os.path.join(stamp_dir, "%s.log" % job_name)
    if os.path.exists(log_file):
        os.remove(log_file)
    f = open(log_file, "a")
    f.write(log)
    f.close()


def run_job(which, interval, args=None):
    stamp_dir = os.path.join(settings.PROJECT_PATH, 'data')
    if not os.path.exists(stamp_dir):
        os.makedirs(stamp_dir)
    stamp_file = os.path.join(stamp_dir, "%s.stamp" % which)
    if not os.path.exists(stamp_file) or \
       datetime.datetime.utcfromtimestamp(os.path.getmtime(stamp_file)) + interval < datetime.datetime.now():
        pwd = os.getcwd()
        os.chdir(settings.PROJECT_PATH)
        p = subprocess.Popen(["python", "manage.py", which], stdout=subprocess.PIPE,
                             stderr=subprocess.STDOUT, close_fds=True)
        log = p.stdout.read()
        p.communicate()
        os.chdir(pwd)
        open(stamp_file, "a").close()
        os.utime(stamp_file, None)
        write_log(which, log)


def flat_list(some_list):
    """
    >>> reduce(lambda a,b: a.extend(b) or a, [[2,3],[6],[66,34]])
    [2, 3, 6, 66, 34]
    """
    if not some_list:
        return []
    return reduce(lambda a, b: a.extend(b) or a, some_list)


class simple_iterator(object):

    def __init__(self, *args):
        self.values = []
        self.index = -1
        if len(args) == 1 and isinstance(args[0], (list, tuple, set)):
            self.values.extend(deepcopy(args[0]))
        else:
            self.values.extend(deepcopy(args))

    def get_next_index(self):
        if self.index + 1 >= len(self.values):
            self.index = 0
        else:
            self.index = self.index + 1
        return self.index
    next_index = property(get_next_index)

    def get_next(self):
        return self.values[self.next_index]
    next = property(get_next)

    def reset(self):
        self.index = -1
        return ''


def check_for_language(lang_code):
    """
    Checks whether there is a global language file for the given language code.
    """
    globalpath = os.path.join(settings.PROJECT_PATH, 'locale')
    for dirnames in os.listdir(globalpath):
        if dirnames == lang_code:
            for dirpath_local, dirnames_local, filenames in os.walk(os.path.join(globalpath, dirnames, 'LC_MESSAGES')):
                if 'django.mo' in filenames:
                    return True
                else:
                    return False


def get_languages():
    """
    Return a language list.
    """
    global languages
    if languages is None:
        from teams.models import Language
        languages = {}
        Languages = Language.objects.order_by('name')
        for language in Languages:
            if check_for_language(language.code):
                languages[language.code] = language.name
        languages['en_US'] = 'English'
        languages = sorted([(value, key) for (key, value) in languages.items()])
    return languages


def slugify(s, ok=SLUG_OK, lower=True, spaces=False):
    # L and N signify letter/number.
    # http://www.unicode.org/reports/tr44/tr44-4.html#GC_Values_Table
    rv = []
    for c in unicodedata.normalize('NFKC', smart_unicode(s)):
        cat = unicodedata.category(c)[0]
        if cat in 'LN' or c in ok:
            rv.append(c)
        if cat == 'Z':  # space
            rv.append(' ')
    new = ''.join(rv).strip()
    if not spaces:
        new = re.sub('[-\s]+', '-', new)
    return new.lower() if lower else new
