# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse
from django.contrib.syndication.feeds import Feed, FeedDoesNotExist
from django.utils.translation import ugettext as _
from django.utils import translation
from django.template import loader, Context

from teams.models import Team
from .models import TeamEvent, GlobalEvent

import datetime


class TeamEventFeed(Feed):
    def get_object(self, bits):
        if len(bits) >= 1:
            try:
                lang = bits[1]
            except IndexError:
                lang = "en_EN"
            translation.activate(lang)
            if bits[0] == 'all':
                return 'all'
            else:
                try:
                    return Team.objects.get(lp_name=bits[0])
                except:
                    raise FeedDoesNotExist
        return None

    def items(self, obj):
        if isinstance(obj, Team):
            return TeamEvent.objects.filter(teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]
        else:
            return TeamEvent.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]

    def title(self, obj):
        template = loader.get_template('feeds/title.html')
        if isinstance(obj, Team):
            title = 'Upcoming Events for %(teamname)s' % {'teamname': obj.name}
        else:
            title = 'Upcoming Events'
        ctx = {"title": title}
        ctx = Context(ctx)
        return template.render(ctx)

    def link(self, obj):
        if isinstance(obj, Team):
            return reverse('team-event-list', kwargs={'team_slug': obj.lp_name})
        else:
            return reverse('event-list')


class GlobalEventFeed(TeamEventFeed):
    def items(self, obj):
        if isinstance(obj, Team):
            return GlobalEvent.objects.filter(teamevent__teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]
        else:
            return GlobalEvent.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]

    def title(self, obj):
        template = loader.get_template('feeds/title.html')
        if isinstance(obj, Team):
            title = 'Upcoming Global Events where %(teamname)s is participating' % {'teamname': obj.name}
        else:
            title = 'Upcoming Global Events'
        ctx = {"title": title}
        ctx = Context(ctx)
        return template.render(ctx)

    def link(self, obj):
        return reverse('event-list')
