# -*- coding: utf-8 -*-
from django.db import models
import datetime


class GlobalEventManager(models.Manager):
    """ manager for a global event """
    def next_events(self):
        """ a list with all upcoming global events """
        return self.filter(date_end__gt=datetime.datetime.now()).order_by('date_end')

    def history_events(self):
        """ all global events in history """
        return self.filter(date_end__lt=datetime.datetime.now()).order_by('date_end')


class TeamEventManager(models.Manager):
    """ manager for a team event """
    def next_3_events(self):
        """ a list with the next 3 events """
        return self.filter(date_end__gt=datetime.datetime.now()).order_by('date_end')[:3]

    def next_5_events(self):
        """ a list with the next 5 events """
        return self.filter(date_end__gt=datetime.datetime.now()).order_by('date_end')[:5]

    def next_events(self):
        """ a list with all upcoming team events """
        return self.filter(date_end__gt=datetime.datetime.now()).order_by('date_end')

    def history_events(self):
        """ all team events in history """
        return self.filter(date_end__lt=datetime.datetime.now()).order_by('-date_end')

    def has_location(self):
        return self.filter(venue__longitude__isnull=False, venue__latitude__isnull=False)
