# -*- coding: utf-8 -*-
"""
This file demonstrates two different styles of tests (one doctest and one
unittest). These will both pass when you run "manage.py test".

Replace these with more appropriate tests for your application.
"""
from django.test import TestCase
from django.contrib.auth.models import User, Group

from teams.models import Country, Team
from venues.models import Venue
from .models import TeamEvent

import datetime


class FormTests(TestCase):

    def setUp(self):
        # setup country record for testing
        self.country = Country.objects.create(name='Test Country')
        # setup team record for testing
        self.team = Team.objects.create(
            lp_name='test-team',
            name='Test Team',
        )
        self.team.countries.add(self.country)
        # setup venue record for testing
        self.venue = Venue.objects.create(
            name='Test Venue',
            country=self.country,
        )
        # setup event record for testing
        self.event = TeamEvent.objects.create(
            name='Test Event',
            date_begin=datetime.datetime.now(),
            date_end=datetime.datetime.now() + datetime.timedelta(hours=1),
            venue=self.venue,
        )
        self.event.teams.add(self.team)
        # setup user record for testing
        self.team_group = Group.objects.create(
            name=self.team.lp_name,
        )
        self.user = User.objects.create(
            username='testuser',
        )
        self.user.set_password('test')
        self.user.groups.add(self.team_group)
        self.user.save()

    def test_large_guest_validation(self):
        'Validate the guests size and show friendly error message when too big'

        # register attendence form data
        path = '/events/%s/%s/register/' % (self.team.lp_name, self.event.id)
        data = {
            'promise': 'sure',
            'guests': 1000000,
        }
        # login so we're not redirected when posting the form data
        self.client.login(username='testuser', password='test')
        # post the form data
        response = self.client.post(path, data)

        # should get a 200 if the integer size is caught by form validation
        self.assertEquals(response.status_code, 200)

        # check that the user friendly error message exists in the response
        self.assertContains(response, 'Ensure this value is less than or equal to 100.')
