/*
 * jQuery Flickr plugin 0.1.0
 * Requires jQuery 1.4.2
 *
 * Copyright 2011, Ronnie van den Crommenacker
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 */

(function ($) {
    $.fn.extend({   
        //This is where you write your plugin's name  
        flickr: function (options) {
            var defaults = {
                key: null,
                id: null,
                tag: null,
                amount: 16,
                lightbox_class: 'lightbox' 
            },
                group = false,
                html_elements = this,
                data = { 
                    format: 'json',
                    method: 'flickr.photos.search',
                    api_key: options.key,
                    per_page: options.amount,
                    jsoncallback: '' 
                };
            options =  $.extend(defaults, options);
            
            function parseResponse(data) {
                var images = [];
                if (data.stat === 'ok') {
                    $.each(data.photos.photo, function (i, rPhoto) {
                        var basePhotoURL = 'http://farm' + rPhoto.farm + '.static.flickr.com/'
                            + rPhoto.server + '/' + rPhoto.id + '_' + rPhoto.secret,
                            image = $('<img>').attr({
                                src: basePhotoURL + '_s.jpg',
                                alt: rPhoto.title
                            }),
                            link = $('<a>').addClass(options.lightbox_class).attr({
                                title: rPhoto.title,
                                href: basePhotoURL + '.jpg'
                            }).append(image);
                        images.push(link);
                    });
                    $(html_elements).each(function (i, html_element) {
                        var index;
                        for (index in images) {
                            if (images.hasOwnProperty(index)) {
                                $(html_element).append(images[index]);
                            }
                        }
                    });
                    // Reinitiale the lightbox with the new photo's
                    $('a.' + options.lightbox_class).lightBox();
                } else {
                    // Error: Unknown user
                    if (data.code === 2 && !group) {
                        // If the user does not exists, maybe its a group id, try that one.
                        group = true;
                        data = { 
                            format: 'json',
                            method: 'flickr.photos.search',
                            api_key: options.key,
                            group_id: options.id,
                            per_page: options.amount,
                        };
                        $.getJSON('http://api.flickr.com/services/rest/?' + $.param(data) + '&jsoncallback=?', parseResponse);
                    } else {
                        // Show the error message
                        $(html_elements).each(function (i, html_element) {
                            $(html_element).append($('<p>').text(data.message));
                        });
                    }
                }
            }
            
            if (options.id) {
                data.user_id = options.id;
            } else if (options.tag) {
                data.tags = options.tag;
            }
            
            $.getJSON('http://api.flickr.com/services/rest/?' + $.param(data) + '&jsoncallback=?', parseResponse);
            
            // Return the html objects untouched (the photo's are added when loaded)
            return this;
        } // End of flickr command
    });
}(jQuery));
