/*
 * jQuery Google Map Plugin 0.2.3
 * https://wiki.ubuntu.com/ubuntu-django-foundations/map
 * Requires jQuery 1.4.2
 *
 * Copyright 2011, Ronnie van den Crommenacker
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 */

(function ($) {
    $.fn.extend({
        showLocations: function (options) {
            var defaults = {
                    markers_url: null,          // http://link/to/json/markers or /link/to/json/markers
                    markers_list: null,         // [ {lat: 0.345, lng: 0.3456}, {lat: 44.345, lng: 34.3456} ]
                    position_name: {
                        lat: 'lat',             // { lat: 0.4567, lng: 0.2345 }
                        lng: 'lng'              // { lat: 0.4567, lng: 0.2345 }
                    },
                    marker_content_url: null,   // The url to load when clicked on a marker
                    marker_content_tmpl: null,  // The template to load when clicked on a marker
                    mapOptions: {
                        zoom: 1,
                        center: new google.maps.LatLng(22, 0),
                        mapTypeId: google.maps.MapTypeId.ROADMAP,
                        mapTypeControl: false
                    },
                    user_location_zoom: 7,      // use null to disable this feature
                    single_marker_zoom: 7,      // the zoomlevel. use null to disable
                    ajax_load_error: '<p>The page could not be loaded</p>',
                    ajax_load_icon: '/ubuntu-website/media/images/ajax-loader.gif',
                    marker_icon: null,
                    cluster_tmpl: null,
                    filter: null, //[ { element: $('...'), attrs: { attr: value }}, { element: $('...'), attrs: { attr: value }} ]
                    mcOptions: { gridSize: 40, maxZoom: 10, zoomOnClick: false//, styles: [
                            //{ url: 'images/supportCluster1.png', height: 48, width: 48, opt_anchor: [16, 0], opt_textColor: '#ffffff', opt_textSize: 10 }, /* 2-9 members */
                            //{ url: 'images/supportCluster2.png', height: 64, width: 64, opt_anchor: [24, 0], opt_textColor: '#ffffff', opt_textSize: 11 }, /* 10-99 members */
                            //{ url: 'images/supportCluster3.png', height: 96, width: 96, opt_anchor: [32, 0], opt_textColor: '#ffffff', opt_textSize: 12 }, /* 100-999 members */
                            //{ url: 'images/supportCluster4.png', height: 128, width: 128, opt_anchor: [32, 0], opt_textColor: '#ffffff', opt_textSize: 12 }  /* 1000+ members */
                        //]
                    }
                },
                // Add the window where the details are shown when clicked on a marker
	            infowindow = new google.maps.InfoWindow();

            options =  $.extend(defaults, options);

            // TODO: rewrite this one
            function getAjaxLoader() {
	            var ajaximg = $('<img src="' + options.ajax_load_icon + '" />')
	                .attr({'style': 'display:inline-block;vertical-align:middle;margin-right:10px;'}),
	                ajaxtxt = $('<p>')
	                .attr({'style': 'display:inline-block;vertical-align:middle;'})
                    .html('Retrieving data<br />from server...'),
                    wrapper = $('<div>')
                    .attr({'style': 'margin:auto;width:130px;'});
	            return wrapper.append(ajaximg).append(ajaxtxt)[0];
            }

            infowindow.show = function (html, pos) {
                this.setContent(html);
                this.setPosition(pos);
                this.open(this.map);
            };
            infowindow.ajaxloader = null;
            infowindow.showLoader = function (pos) {
                // Set a temporary loader while the data is retreved from the server
                if (this.ajaxloader === null) {
                    // TODO: allow user defined ajax loader
	                this.ajaxloader = getAjaxLoader();
                }
                this.show(this.ajaxloader, pos);
            };
            infowindow.showTemplate = function (url, data, pos) {
                var $data = data,
                    $pos = pos,
                    ifw = this;

                if (!$.tmpl) {
                    alert('jQuery.tmpl is not installed\nYou can download here:\nhttp://github.com/jquery/jquery-tmpl');
                    return false;
                }

                this.showLoader(pos);
                $.ajax({
                    url: url,
                    dataType: 'html',
                    success: function (template) {
                        ifw.show($(template).tmpl($data)[0], $pos);
                    },
                    error: function () {
                        ifw.show(options.ajax_load_error, $pos);
                    }
                });
            };
            infowindow.showHTML = function (url, pos) {
                var $pos = pos,
                    ifw = this;

                this.showLoader(pos);
                //TODO: Check for better same-origin in url
                if (url.slice(0, 4) == 'http'){
                    ifw.show($('<iframe>').attr('src', url)[0], $pos);
                } else {
	                $.ajax({
	                    url: url,
                        dataType: 'html',
                        success: function (html) {
                            ifw.show(html, $pos);
                        },
                        error: function () {
                            ifw.show(options.ajax_load_error, $pos);
                        }
                    });
                }
            };

            // Constructs an url with ${...} together with data to a normal url
            function constructUrl(url, marker) {
                var pattern = /\$\{[\w\d]+\}/g,     // match pattern for ${....}
	                url_match = url.match(pattern), // Matches the url for ${...} and returns a list of matches
	                param = null,                   // Used for getting a specific param from the marker
	                tag = null;                     // The tags in the match pattern

	            for (tag in url_match) {
	                if (url_match.hasOwnProperty(tag)) {
	                    param = url_match[tag];
                        url = url.replace(param, marker[param.slice(2, param.length - 1)]);
	                }
	            }
                return url;
            }

            // Function executed when clicked on a cluster object
            function clusterClicked(cluster) {
	            if (options.cluster_tmpl) {
                    infowindow.showTemplate(options.cluster_tmpl, {marker_list: cluster[0].markers_}, cluster[0].getCenter());
                }
            }

            // Function that is executed when user clicks on a marker
            function markerClicked() {
                var url = null;

                if (options.marker_content_url) {
                    url = constructUrl(options.marker_content_url, this);
                    infowindow.showHTML(url, this.position);
                } else if (options.marker_content_tmpl) {
                    infowindow.showTemplate(options.marker_content_tmpl, {marker: this}, this.position);
                }
            }

            // Create from json data the google.maps.Marker and add them to the markercluster (mc)
            // Then center the map if there is only one cluster and options.single_marker_zoom is true
            function createMarkers(map, mc, markers) {
                var marker_list = [],           // A list of gmakers
                    marker = null,              // The json of a marker
                    gmarker = null,             // The actual google.maps.Marker() type
                    idx = null,                 // Index
                    lat = options.position_name.lat,  // The parameter that contains the latitude
                    lng = options.position_name.lng;  // The parameter that contains the longitude

                if (markers[0].fields) {
                    // Django model
                    // Use django pk and fields parameters
                    for (idx in markers) {
                        if (markers.hasOwnProperty(idx)) {
                            marker = markers[idx].fields;
                            marker.pk = markers[idx].pk;
                            marker.position = new google.maps.LatLng(marker[lat], marker[lng]);
                            if (!marker.icon && options.marker_icon) {
                                marker.icon = options.marker_icon;
                            }
                            gmarker = new google.maps.Marker(marker);
                            google.maps.event.addDomListener(gmarker, 'click', markerClicked);
                            marker_list.push(gmarker);
                        }
                    }

                } else {
                    // Use normal parameters
                    for (idx in markers) {
                        if (markers.hasOwnProperty(idx)) {
                            marker = markers[idx];
                            marker.position = new google.maps.LatLng(marker[lat], marker[lng]);
                            if (!markers[idx].icon && options.marker_icon) {
                                marker.icon = options.marker_icon;
                            }
                            gmarker = new google.maps.Marker(marker);
                            google.maps.event.addDomListener(gmarker, 'click', markerClicked);
                            marker_list.push(gmarker);
                        }
                    }
                }
                mc.addMarkers(marker_list);

                // If there is only one marker
                if (options.single_marker_zoom && marker_list.length === 1) {
                    // Make sure the map is initialized
                    // FIXME: Look for an map.init event
                    setTimeout(function () {
                        map.setCenter(mc.getMarkers()[0].getPosition());
                        map.setZoom(options.single_marker_zoom);
                    }, 100);
                }
            }

            return $(this).each(function (i, html_element) {
                var map = new google.maps.Map(html_element, options.mapOptions),
                    markerCluster = new MarkerClusterer(map, [], options.mcOptions),
                    filter = options.filter,
                    filterer = null,
                    index = null,
                    pos = null;

                // FIXME: Manually override the zoomOnClick because of this bug
                // http://www.devcomments.com/V3-MarkerClusterer-zoomOnClick-issue-at255452.htm
                markerCluster.zoomOnClick_ = false;

                // Attach the info window to the curernt map
                infowindow.map = map;

                // When clicked on a cluster, call the event
                google.maps.event.addListener(markerCluster, 'clusterclick', clusterClicked);

                // Try W3C Geolocation (Preferred)
                // Ask the user for their location and set the map to it
                if (options.user_location_zoom && navigator.geolocation) {
	                navigator.geolocation.getCurrentPosition(function (position) {
		                pos = new google.maps.LatLng(position.coords.latitude, position.coords.longitude);
		                map.setCenter(pos);
		                map.setZoom(options.user_location_zoom);
	                });
                }

                // Load the list of markers into the map
                if (options.markers_url) {
                    $.getJSON(options.markers_url, function (markers) {
                        createMarkers(map, markerCluster, markers);
                    }, 'json');
                } else if (options.markers_list) {
                    createMarkers(map, markerCluster, options.markers_list);
                }

                if (filter) {
                    filterer = (function (markerCluster) {
                        var mc = markerCluster,
                            markers = mc.getMarkers();
                        return {
                            addFilter: function (filter) {
                                filter.element.click(function (event) {
                                    var attrs = filter.attrs,
                                        visible_markers = [],
                                        m = null,
                                        a = null;

                                    event.preventDefault();

                                    for (m in markers) {
                                        if (markers.hasOwnProperty(m)) {
                                            marker = markers[m];
                                            for (a in attrs) {
                                                if (attrs.hasOwnProperty(a)) {
                                                    if (marker[a] === attrs[a]) {
                                                        visible_markers.push(marker);
                                                    }
                                                }
                                            }
                                        }
                                    }
                                    // If there are no filter options, show all markers
                                    if (!a) {
                                        visible_markers = markers;
                                    }
                                    mc.clearMarkers();
                                    mc.addMarkers(visible_markers, false);
                                });
                            }
                        };
                    }(markerCluster));
                    for (index in filter) {
                        if (filter.hasOwnProperty(index)) {
                            filterer.addFilter(filter[index]);
                        }
                    }
                }
            });
        },
        selectLocation: function (options) {
            var defaults = {
                html_lng: null,
                html_lat: null,
                html_tz: null,
                html_country: null,
                html_continent: null,
                marker_icon: null,
                markers: [],
                html_addr: null,
                mapOptions: {
                    zoom: 4,
                    center: new google.maps.LatLng(51.8211, 5.591),
                    mapTypeId: google.maps.MapTypeId.ROADMAP,
                    mapTypeControl: false
                }
            };
            options = $.extend(defaults, options);

            function showPositionHTML(location) {
                var geocoder = new google.maps.Geocoder();
                geocoder.geocode({'latLng': location}, function(results, status) {
                    if (status == google.maps.GeocoderStatus.OK) {
                        if (results[0]) {
                            $('#id_address').val(results[0].formatted_address);

                            $.each(results[0].address_components, function(){
                                if(this.types[0]=="locality"){
                                    $('#id_city').val(this.long_name);
                                }
                            });
                        }
                    }
                });

                if (options.html_lng && options.html_lat) {
                    if (location.lat() && location.lng()) {
                        options.html_lat.val(location.lat());
                        options.html_lng.val(location.lng());
                        if (options.html_tz && options.html_country && options.html_continent) {
                            $.getJSON("http://ws.geonames.org/timezoneJSON?lat=" + location.lat() + "&lng=" + location.lng(),
                                function(json) {
                                    $(options.html_tz).filter(function() {
                                        return $(this).text() == json.timezoneId;
                                    }).prop('selected', true);

                                    $(options.html_country).filter(function() {
                                        return $(this).text() == json.countryName;
                                    }).prop('selected', true);

                                    $.getJSON("http://ws.geonames.org/countryInfoJSON?country=" + json.countryCode,
                                        function(json) {
                                            if (typeof json.geonames[0].continentName !== "undefined") {
                                                $(options.html_continent).filter(function() {
                                                    return $(this).text() == json.geonames[0].continentName;
                                                }).prop('selected', true);
                                            }
                                        }
                                    );
                                }
                            );
                        }
                    }
                }


            }

            function setMarker(map, location) {
                var marker = null;

                if (options.markers.length) {
                    marker = options.markers[0];
                    marker.setPosition(location);
                    marker.setAnimation(google.maps.Animation.DROP);
                } else {
                    marker = new google.maps.Marker({
                        map: map,
                        position: location,
                        draggable: true,
                        animation: google.maps.Animation.DROP
                    });
                    if (options.marker_icon) {
                        marker.icon = options.marker_icon;
                    }
                    options.markers.push(marker);
                    google.maps.event.addListener(options.markers[0], 'mouseup', function () {
                        showPositionHTML(marker.getPosition());
                    });
                }

                map.setCenter(location);
                showPositionHTML(marker.getPosition());
            }

            return $(this).each(function (i, html_element) {
                var map = new google.maps.Map($(html_element)[0], options.mapOptions),
                    geoCoder = new google.maps.Geocoder(),
                    location = null;

                if (options.html_addr) {
                    options.html_addr.change(function () {
                        var address = [];
                        options.html_addr.each(function (i, item) {
                            address.push(item.value);
                        });

                        geoCoder.geocode({address: address.join(' ')}, function (results, status) {
                            if (status === google.maps.GeocoderStatus.OK) {
                                setMarker(map, results[0].geometry.location);
                            }
                        });
                    });
                }
                google.maps.event.addListener(map, 'click', function (event) {
                    setMarker(map, event.latLng);
                });

                if (options.html_lat.val() && options.html_lng.val()) {
                    location = new google.maps.LatLng(options.html_lat.val(), options.html_lng.val());
                    setMarker(map, location);
                }
            });

        }
    });
}(jQuery));
