# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse
from django.contrib.syndication.feeds import Feed, FeedDoesNotExist
from django.utils import translation
from django.template import loader, Context


from meetings.models import TeamMeeting
from teams.models import Team

import datetime


class TeamMeetingFeed(Feed):
    def get_object(self, bits):
        if len(bits) >= 1:
            try:
                lang = bits[1]
            except IndexError:
                lang = "en_EN"
            translation.activate(lang)
            if bits[0] == 'all':
                return 'all'
            else:
                try:
                    return Team.objects.get(lp_name=bits[0])
                except:
                    raise FeedDoesNotExist
        return None

    def items(self, obj):
        if isinstance(obj, Team):
            return TeamMeeting.objects.filter(teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]
        else:
            return TeamMeeting.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]

    def title(self, obj):
        template = loader.get_template('feeds/title.html')
        if isinstance(obj, Team):
            title = 'Upcoming Meetings for %(teamname)s' % {'teamname': obj.name}
        else:
            title = 'Upcoming Meetings'
        ctx = {"title": title}
        ctx = Context(ctx)
        return template.render(ctx)

    def link(self, obj):
        if isinstance(obj, Team):
            return reverse('team-meeting-list', kwargs={'team_slug': obj.lp_name})
        else:
            return reverse('meeting-list')
