# -*- coding: utf-8 -*-
from django.contrib.syndication.feeds import Feed, FeedDoesNotExist
from django.utils.translation import ugettext as _
from django.utils import translation

from meetings.models import TeamMeeting
from events.models import TeamEvent
from teams.models import Team

import datetime


class TeamFeed(Feed):

    def get_object(self, bits):
        if len(bits) >= 1:
            try:
                lang = bits[1]
            except IndexError:
                lang = "en_EN"
            translation.activate(lang)
            if bits[0] == 'all':
                return 'all'
            else:
                try:
                    return Team.objects.get(lp_name=bits[0])
                except:
                    raise FeedDoesNotExist
        return None

    def items(self, obj):
        if isinstance(obj, Team):
            meetings = TeamMeeting.objects.filter(teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')
            events = TeamEvent.objects.filter(teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')
        else:
            meetings = TeamMeeting.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')
            events = TeamEvent.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')

        events_and_meetings = []
        events = events[:15].iterator()
        meetings = meetings[:15].iterator()
        for event in events:
            events_and_meetings.append(event)
        for meeting in meetings:
            events_and_meetings.append(meeting)

        events_and_meetings.sort(key=lambda event: event.date_begin)
        return events_and_meetings

    def title(self, obj):
        if isinstance(obj, Team):
            return _('Upcoming Events and Meetings for %(teamname)s' % {'teamname': obj.name})
        else:
            return _('Upcoming Events and Meetings')

    def link(self, obj):
        if isinstance(obj, Team):
            return obj.get_absolute_url()
        else:
            return '/'
