# -*- coding: utf-8 -*-
#!/usr/bin/python

from django.core.management.base import NoArgsCommand
from django.contrib.auth.models import Group, User

from common import launchpad
from userprofiles.models import create_userprofile

import sys
import logging
st_handler = logging.StreamHandler(sys.stderr)
formatter = logging.Formatter("[%(asctime)s] - %(levelname)s - %(module)s - %(message)s")
st_handler.setFormatter(formatter)

log = logging.getLogger(__name__)
log.addHandler(st_handler)
log.setLevel(logging.DEBUG)


class Command(NoArgsCommand):
    help = "Pull the LoCo Council members and add them to the DB."

    def handle_noargs(self, **options):
        lp = launchpad.lp_login()
        if not lp:
            sys.exit(1)
        g = Group.objects.get(name='ubuntu-lococouncil')
        users = g.user_set.all()
        log.debug("Removing all members.")
        for u in users:
            g.user_set.remove(u)
        lc_members = lp.people["ubuntu-lococouncil"].members
        for member in lc_members:
            try:
                user = User.objects.get(username=member.name)
                create_userprofile(sender=User, instance=user, need_update=True)
                log.debug("Adding member %s." % user)
                g.user_set.add(user)
            except User.DoesNotExist:
                log.debug("User %s doesn't exist" % member.name)
