from django.utils.translation import ugettext

from events.models import TeamEvent


def merge_teams(old_team, new_team):
    msgs = []
    related_events = TeamEvent.objects.filter(teams__id=old_team.id)
    for event in related_events:
        for team in event.teams.filter(id=old_team.id):
            msgs += [ugettext('New owner of event "%(event)s" is team "%(team)s".' % {'event':event.name, 'team':new_team.name})]
            event.teams.remove(team)
            event.teams.add(new_team)
        event.save()
    if old_team.contact_profiles.count() and not new_team.contact_profiles.count():
        for contact_profile in old_team.contact_profiles.all():
            new_team.contact_profiles.add(contact_profile)
            msgs += [ugettext('Adding contact "%(contact)s" to team "%(team)s".' % {'contact': contact_profile.realname, 'team': new_team.name})]
    if old_team.countries.count() and not new_team.countries.count():
        for country in old_team.countries.all():
            new_team.countries.add(country)
            msgs += [ugettext('Adding country "%(country)s" to team "%(team)s".' % {'country':country.name, 'team':new_team.name})]
    if old_team.languages.count() and not new_team.languages.count():
        for language in old_team.languages.all():
            new_team.languages.add(language)
            msgs += [ugettext('Adding language "%(language)s" to team "%(team)s".' % {'language':language.name, 'team':new_team.name})]
    if old_team.spr and not new_team.spr:
        new_team.spr = old_team.spr
        msgs += [ugettext('Setting State/Province/Region of "%(team)s" to "%(region)s".' % {'team':new_team.name, 'region':old_team.spr})]
    if old_team.city and not new_team.city:
        new_team.city = old_team.city
        msgs += [ugettext('Setting city of "%(team)s" to "%(city)s".' % {'team':new_team.name, 'city':old_team.city})]
    if old_team.wiki_url and not new_team.wiki_url:
        new_team.wiki_url = old_team.wiki_url
        msgs += [ugettext('Setting Wiki URL of "%(team)s" to "%(url)s".' % {'team':new_team.name, 'url':old_team.wiki_url})]
    if old_team.web_url and not new_team.web_url:
        new_team.web_url = old_team.web_url
        msgs += [ugettext('Setting Web URL of "%(team)s" to "%(url)s".' % {'team':new_team.name, 'url':old_team.web_url})]
    if old_team.ml_url and not new_team.ml_url:
        new_team.ml_url = old_team.ml_url
        msgs += [ugettext('Setting Mailing list URL of "%(team)s" to "%(url)s".' % {'team':new_team.name, 'url':old_team.ml_url})]
    if old_team.forum_url and not new_team.forum_url:
        new_team.forum_url = old_team.forum_url
        msgs += [ugettext('Setting Forum URL of "%(team)s" to "%(url)s".' % {'team':new_team.name, 'url':old_team.forum_url})]
    if old_team.email and not new_team.email:
        new_team.email = old_team.email
        msgs += [ugettext('Setting email address of "%(team)s" to "%(email)s".' % {'team':new_team.name, 'email':old_team.email})]
    if old_team.irc_chan and not new_team.irc_chan:
        new_team.irc_chane = old_team.irc_chan
        msgs += [ugettext('Setting IRC channel of "%(team)s" to "%(channel)s".' % {'team':new_team.name, 'channel':old_team.irc_chan})]
    if old_team.flickr_id and not new_team.flickr_id:
        new_team.flickr_id = old_team.flickr_id
        msgs += [ugettext('Setting Flickr ID of "%(team)s" to "%(id)s".' % {'team':new_team.name, 'id':old_team.flickr_id})]
    if old_team.picasa_id and not new_team.picasa_id:
        new_team.picasa_id = old_team.picasa_id
        msgs += [ugettext('Setting Picasa ID of "%(team)s" to "%(id)s".' % {'team':new_team.name, 'id':old_team.picasa_id})]
    if old_team.pixie_id and not new_team.pixie_id:
        new_team.pixie_id = old_team.pixie_id
        msgs += [ugettext('Setting Pix.ie ID of "%(team)s" to "%(id)s".' % {'team':new_team.name, 'id':old_team.pixie_id})]
    new_team.save()
    old_team.delete()
    msgs += [ugettext('Team "%(old_team)s" merged with "%(new_team)s".' % {'old_team':old_team.name, 'new_team':new_team.name})]
    return msgs
