from django.conf.urls.defaults import *
from django.conf import settings
from django.contrib import admin
import ubuntu_website

from common.views import login_failure

admin.autodiscover()

from events.feeds import TeamEventFeed, GlobalEventFeed
from meetings.feeds import TeamMeetingFeed
from teams.feeds import TeamFeed

feeds = {
    'teams': TeamFeed,
    'events': TeamEventFeed,
    'globalevents': GlobalEventFeed,
    'meetings': TeamMeetingFeed,
}

urlpatterns = patterns('',
    url(r'^$', 'common.views.index', name='home'),
    url(r'^language/', 'common.views.set_language', name='set_language'),
    url(r'^about/$', 'common.views.about', name='about'),
    url(r'^irc/$', 'common.views.irc_chat', name='irc_chat'),
    url(r'^about-loco/setup/$', 'common.views.loco_setup', name='loco_setup'),
    url(r'^about-loco/$', 'common.views.about_loco', name='about_loco'),
    url(r'^using-locodir/$', 'common.views.using_locodir', name='using_locodir'),
    (r'^admin/', include(admin.site.urls)),
    url(r'^data/xml', 'teams.views.xml_team_data', name='xml_team_data'),
    url(r'^teams/', include('teams.urls')),
    url(r'^planet/', include('articles.urls')),
    url(r'^events/venues/', include('venues.urls')),
    url(r'^events/', include('events.urls')),
    url(r'^meetings/', include('meetings.urls')),
    url(r'^loco-council/$', 'teams.views.loco_council', name='loco_council'),
    url(r'^loco-council/edit$', 'teams.views.loco_council_edit', name='lc_edit'),
    url(r'^loco-council/approved/$', 'teams.views.reapprovals', name='reapprovals-old'),
    url(r'^loco-council/verified/$', 'teams.views.verified', name='reapprovals'),

    url(r'^logout$', 'common.views.site_logout', name='logout'),
    url(r'^jsi18n', 'django.views.i18n.javascript_catalog', name='jsi18n'),
    url(r'^services/', include('services.urls')),
    url(r'^search/', 'common.views.site_search', name='site_search'),
    url(r'^feeds/(?P<url>.*)/$', 'django.contrib.syndication.views.feed', {'feed_dict': feeds}, name='feed_view'),
    url(r'^', include('userprofiles.urls')),
)

urlpatterns += patterns('django_openid_auth.views',
    url(r'^openid/login/$', 'login_begin', name='openid-login',
        kwargs={'render_failure': login_failure}),
    url(r'^openid/complete/$', 'login_complete', name='openid-complete',
        kwargs={'render_failure': login_failure}),
    url(r'^openid/logo.gif$', 'logo', name='openid-logo'),
)

if settings.STATIC_SERVE:
    urlpatterns += patterns('',
        (r'^media/(?P<path>.*)$', 'django.views.static.serve',
            {'document_root': settings.MEDIA_ROOT}),
        (r'^(robots.txt)$', 'django.views.static.serve',
            {'document_root': settings.MEDIA_ROOT}),
        (r'^ubuntu-website/media/(?P<path>.*)$', 'django.views.static.serve',
            {'document_root': ubuntu_website.MEDIA_ROOT}),
    )
