# -*- coding: utf-8 -*-
from django.shortcuts import render_to_response,  get_object_or_404
from django.template import RequestContext
from django.contrib.auth.models import User
from django.db.models import Count

from userprofiles.models import UserProfile
from teams.models import Team
from events.models import TeamEvent


def profile_detail(request, username):
    user = get_object_or_404(User, username__iexact=username)
    teams = Team.objects.filter(lp_name__in=[group.name for group in user.groups.all()])

    if request.user == user:
        profile = request.user.get_profile()
        my_events = TeamEvent.objects.next_events().annotate(attendees=Count('attendee')).filter(attendee__attendee_profile=profile)
    else:
        profile = UserProfile.objects.get(user=user)
        my_events = {}

    context = {
        'profile': profile,
        'teams': teams,
        'my_events': my_events,
    }

    return render_to_response('profiles/details.html', context, context_instance=RequestContext(request))
