"""
This file demonstrates two different styles of tests (one doctest and one
unittest). These will both pass when you run "manage.py test".

Replace these with more appropriate tests for your application.
"""

from django.test import TestCase
from teams.models import Country, Team
from venues.models import Venue


class ViewTests(TestCase):

    def setUp(self):
        self.country = Country.objects.create(name='Test Country')
        self.team = Team.objects.create(
            lp_name='test-team',
            name='Test Team',
        )
        self.team.countries.add(self.country)
        self.venue = Venue.objects.create(
            name='Test Venue',
            country=self.country,
        )

    def test_venue_list(self):
        response = self.client.get('/events/venues/')

        # Check that the country group is labeled
        self.assertContains(response, 'Test Country', 1)

        # Check that the venue name is displayed
        self.assertContains(response, 'Test Venue', 1)

        # Check that the venue details URL exists using the propert country slug
        self.assertContains(response, 'href="/events/venues/Test_Country/%s/detail/"' % self.venue.id, 1)

    def test_venue_details_subnav(self):
        response = self.client.get('/events/venues/Test_Country/%s/detail/' % self.venue.id)

        # Check edit url exists using the proper country slug
        self.assertContains(response, 'href="/events/venues/Test_Country/%s/edit/"' % self.venue.id)

    def test_country_contains_comma(self):
        self.country.name = 'Korea, Republic of'
        self.country.save()

        # Check list view
        response = self.client.get('/events/venues/')
        self.assertContains(response, 'Korea, Republic of', 1)
        self.assertContains(response, 'href="/events/venues/Korea_Republic_of/%s/detail/"' % self.venue.id, 1)

        # Check details view
        response = self.client.get('/events/venues/Test_Country/%s/detail/' % self.venue.id)
        self.assertContains(response, 'href="/events/venues/Korea_Republic_of/%s/edit/"' % self.venue.id)
