from django.template import RequestContext
from django.shortcuts import render_to_response
from django.shortcuts import get_object_or_404
from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseRedirect
from django.utils.translation import ugettext as _
from django.utils.html import escape

from teams.models import Continent
from venues.models import Venue
from venues.forms import VenueForm

from common.utils import simple_iterator


def venue_list(request):
    """
    a list with all venues
    """
    venue_base_query = Venue.objects.select_related('country').order_by('country')

    continent_list = []
    for continent in Continent.objects.filter(country__venue__isnull=False).distinct():
        continent.venue_list = venue_base_query.filter(country__continents=continent)
        continent_list.append(continent)

    venues_with_country = venue_base_query.filter(country__isnull=False, country__continents__isnull=True)
    venues__without_country = venue_base_query.filter(country__isnull=True)

    context = {
        'continent_list': continent_list,
        'venues_with_country': venues_with_country,
        'venues_without_country': venues__without_country,
        'colcycle': simple_iterator('col_left', 'col_right'),

    }
    return render_to_response('venues/venue_list.html', context,
                  RequestContext(request))


def venue_detail(request, country, venue_id):
    """
    detailed view for a venue
    """
    venue = get_object_or_404(Venue, pk=venue_id)
    events = venue.teamevent_set.next_5_events()
    context = {
        'venue': venue,
        'events': events,
    }
    return render_to_response('venues/venue_detail.html',
                                         context, RequestContext(request))


@login_required
def venue_new(request):
    """
    new venue
    """
    venue_object = Venue()
    if request.method == 'POST':
        form = VenueForm(data=request.POST, instance=venue_object)
        if form.is_valid():
            form.save()
            if request.REQUEST.has_key('_popup'):
                return HttpResponse('<script type="text/javascript">opener.dismissAddAnotherPopup(window, "%s", "%s");</script>' % \
                    # escape() calls force_unicode.
                    (escape(venue_object.pk), escape(venue_object)))
            else:
                return HttpResponseRedirect(venue_object.get_absolute_url())
    else:
        form = VenueForm()

    context = {
        'form': form,
    }
    return render_to_response('venues/venue_update.html',
                                     context, RequestContext(request))


@login_required
def venue_update(request, country, venue_id):
    """
 update venue
    """
    venue_object = get_object_or_404(Venue, pk=venue_id)

    if request.method == 'POST':
        form = VenueForm(data=request.POST, instance=venue_object)
        if form.is_valid():
            form.save()
            request.user.message_set.create(message=_('Venue updated'))
            return HttpResponseRedirect(venue_object.get_absolute_url())
    else:
        form = VenueForm(instance=venue_object)

    context = {
        'form': form,
        'venue_object': venue_object,
    }
    return render_to_response('venues/venue_update.html',
                                     context, RequestContext(request))
